Slot: id_prefixes - LinkML Model

# Slot: id_prefixes

the identifier of this class or slot must begin with the URIs referenced by this prefix

URI: linkml:id_prefixes

## Domain and Range

Element → 0..* Ncname

## Parents

## Children

## Used by

- ClassDefinition
- Definition
- Element
- EnumDefinition
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Comments: |  | Order of elements may be used to indicate priority order
|  | If identifiers are treated as CURIEs, then the CURIE must start with one of the indicated prefixes followed by `:` (should start if the list is open)
|  | If identifiers are treated as URIs, then the URI string must start with the expanded for of the prefix (should start if the list is open)
See also: |  | https://github.com/linkml/linkml/issues/194
|  | https://github.com/linkml/linkml-model/issues/28